@@ -1,15 +1,15 @@
-## ---- echo = FALSE, warning=FALSE, message = FALSE, results = 'hide'----------
+## ----echo = FALSE, warning=FALSE, message = FALSE, results = 'hide'-----------
 cat("this will be hidden; use for general initializations.\n")
 library(superb)
 library(ggplot2)
 options(superb.feedback = c('design','warnings') )
 
-## ---- eval=FALSE, message=FALSE, warning=FALSE--------------------------------
+## ----eval=FALSE, message=FALSE, warning=FALSE---------------------------------
 #  library(ggplot2)            # for the graphing commands
 #  library(superb)             # for superbPlot and GRD
 #  library(referenceIntervals) # for computing reference intervals
 
-## ---- eval=TRUE, message=FALSE, warning=FALSE, echo=FALSE---------------------
+## ----eval=TRUE, message=FALSE, warning=FALSE, echo=FALSE----------------------
 # the above pretend that referenceInterval was installed, but it is not installed
 # because its dependencies (gWidgets2tcltk, extremeValues) crashes travis-CI.com and shinyapps.io...
 # I reproduce the relevant code here as is
@@ -490,21 +490,21 @@ cihiRI.mean <<- function(data, gamma = c(0.95, 0.90) ) {
 
 
 
-## ---- message=FALSE, echo=TRUE------------------------------------------------
+## ----message=FALSE, echo=TRUE-------------------------------------------------
 glucoselevels <- GRD(BSFactors = "concentration(A,B,C,D,E)", 
                     SubjectsPerGroup = 100,
                     RenameDV = "gl",
                     Effects = list("concentration" = extent(10) ),
                     Population = list(mean = 100, stddev = 20) ) 
 
-## ---- message=FALSE, echo=FALSE-----------------------------------------------
+## ----message=FALSE, echo=FALSE------------------------------------------------
 # as the package referenceIntervals cannot accommodate numbers below zero, lets remove them
 glucoselevels$gl[glucoselevels$gl<10]<-10
 
 ## -----------------------------------------------------------------------------
 head(glucoselevels)
 
-## ---- message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 1**. Mean glucose level as a function of concentration."----
+## ----message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 1**. Mean glucose level as a function of concentration."----
 superbPlot(glucoselevels, 
             BSFactors = "concentration",  
             variables = "gl", 
@@ -517,12 +517,12 @@ superbPlot(glucoselevels,
 min(glucoselevels$gl)
 max(glucoselevels$gl)
 
-## ---- eval=FALSE, message=FALSE, warning=FALSE, echo=TRUE---------------------
+## ----eval=FALSE, message=FALSE, warning=FALSE, echo=TRUE----------------------
 #  RI.mean <- function(data, gamma = 0.95) {
 #      refLimit(data, refConf = gamma)$Ref_Int
 #  }
 
-## ---- message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 2**. Mean glucose level and 95% reference intervals as a function of concentration."----
+## ----message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 2**. Mean glucose level and 95% reference intervals as a function of concentration."----
 superbPlot(glucoselevels, 
             BSFactors = "concentration",  
             variables = "gl", 
@@ -531,7 +531,7 @@ superbPlot(glucoselevels,
             gamma     = 0.95,   # select the coverage desired
             plotStyle = "line" )
 
-## ---- eval=FALSE, message=FALSE, warning=FALSE, echo=TRUE---------------------
+## ----eval=FALSE, message=FALSE, warning=FALSE, echo=TRUE----------------------
 #  ciloRI.mean <- function(data, gamma = c(0.95, 0.90) ) {
 #      refLimit(data, refConf = gamma[1], limitConf = gamma[2] )$Conf_Int[1:2]
 #  }
@@ -539,7 +539,7 @@ superbPlot(glucoselevels,
 #      refLimit(data, refConf = gamma[1], limitConf = gamma[2] )$Conf_Int[3:4]
 #  }
 
-## ---- message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3**. Mean glucose level and 90% confidence intervals of the upper RI tips."----
+## ----message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3**. Mean glucose level and 90% confidence intervals of the upper RI tips."----
 superbPlot(glucoselevels, 
             BSFactors = "concentration",  
             variables = "gl", 
@@ -557,14 +557,14 @@ ornate = list(
         theme_light(base_size=10) # smaller font
 )
 
-## ---- message=FALSE-----------------------------------------------------------
+## ----message=FALSE------------------------------------------------------------
 plt1 <- superbPlot(glucoselevels, 
             BSFactors = "concentration",  
             variables = "gl", 
             statistic = "mean", 
             errorbar  = "RI",
             gamma     = 0.95,
-            errorbarParams = list(width = 0.0, size = 1.5,
+            errorbarParams = list(width = 0.0, linewidth = 1.5,
                                   position = position_nudge( 0.0) ),
             plotStyle = "line" ) + ornate
 plt2 <- superbPlot(glucoselevels, 
@@ -573,7 +573,7 @@ plt2 <- superbPlot(glucoselevels,
             statistic = "mean", 
             errorbar  = "cihiRI",
             gamma     = c(0.95, 0.90),
-            errorbarParams = list(width = 0.2, size = 0.2, color = "red",
+            errorbarParams = list(width = 0.2, linewidth = 0.2, color = "red",
                                   direction = "left",
                                   position = position_nudge(-0.15) ),
             plotStyle = "line" ) + ornate + makeTransparent()
@@ -583,12 +583,12 @@ plt3 <- superbPlot(glucoselevels,
             statistic = "mean", 
             errorbar  = "ciloRI",
             gamma     = c(0.95, 0.90),
-            errorbarParams = list(width = 0.2, size = 0.2, color = "purple",
+            errorbarParams = list(width = 0.2, linewidth = 0.2, color = "purple",
                                   direction = "left",
                                   position = position_nudge(-0.15) ),
             plotStyle = "line" ) + ornate + makeTransparent()
 
-## ---- message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3a**. Mean glucose level and 95% reference intervals with 95% confidence intervals."----
+## ----message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3a**. Mean glucose level and 95% reference intervals with 95% confidence intervals."----
 # transform the three plots into visual objects
 plt1 <- ggplotGrob(plt1)
 plt2 <- ggplotGrob(plt2)
@@ -600,7 +600,7 @@ ggplot() +
     annotation_custom(grob=plt2) + 
     annotation_custom(grob=plt3)
 
-## ---- message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3b**. Jittered dots showing mean glucose level and 95% reference intervals with 95% confidence intervals."----
+## ----message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3b**. Jittered dots showing mean glucose level and 95% reference intervals with 95% confidence intervals."----
 # redo plt1; the other 2 are still in memory
 plt1 <- superbPlot(glucoselevels, 
             BSFactors = "concentration",  
@@ -608,7 +608,7 @@ plt1 <- superbPlot(glucoselevels,
             statistic = "mean", 
             errorbar  = "RI",
             gamma     = 0.95,
-            errorbarParams = list(width = 0.0, size = 1.5,
+            errorbarParams = list(width = 0.0, linewidth = 1.5,
                                   position = position_nudge( 0.0) ),
             plotStyle = "pointjitter" ) + ornate
 
@@ -621,7 +621,7 @@ ggplot() +
     annotation_custom(grob=plt2) + 
     annotation_custom(grob=plt3)
 
-## ---- message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3c**. Jittered dots and violins showing mean glucose level and 95% reference intervals with 95% confidence intervals of the tips' position."----
+## ----message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3c**. Jittered dots and violins showing mean glucose level and 95% reference intervals with 95% confidence intervals of the tips' position."----
 # redo plt1; the other 2 are still in memory
 plt1 <- superbPlot(glucoselevels, 
             BSFactors = "concentration",  
@@ -629,7 +629,7 @@ plt1 <- superbPlot(glucoselevels,
             statistic = "mean", 
             errorbar  = "RI",
             gamma     = 0.95,
-            errorbarParams = list(width = 0.0, size = 1.5,
+            errorbarParams = list(width = 0.0, linewidth = 1.5,
                                   position = position_nudge( 0.0) ),
             plotStyle = "pointjitterviolin" ) + ornate
 
@@ -642,18 +642,18 @@ plt1 <- ggplotGrob(plt1)
 #    annotation_custom(grob=plt2) + 
 #    annotation_custom(grob=plt3)
 
-## ---- message=FALSE-----------------------------------------------------------
+## ----message=FALSE------------------------------------------------------------
 plt4 <- superbPlot(glucoselevels, 
             BSFactors = "concentration",  
             variables = "gl", 
             statistic = "mean", 
             errorbar  = "CI",  # just the regular CI of the mean
-            errorbarParams = list(width = 0.2, size = 1.5, color = "blue",
+            errorbarParams = list(width = 0.2, linewidth = 1.5, color = "blue",
                                   position = position_nudge( 0.00) ),
             gamma     = 0.95,
             plotStyle = "line" ) + ornate + makeTransparent()
 
-## ---- message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3d**. Jittered dots and violins showing mean glucose level +-95% confidence intervals of the mean, and 95% reference intervals with 95% confidence intervals."----
+## ----message=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3d**. Jittered dots and violins showing mean glucose level +-95% confidence intervals of the mean, and 95% reference intervals with 95% confidence intervals."----
 # transform that plot too into visual objects
 plt4 <- ggplotGrob(plt4)
 
